@@ -4,7 +4,7 @@
    */
 
 /*
- * Copyright 2007-2009 Roy Marples <roy@marples.name>
+ * Copyright (c) 2007-2009 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -31,7 +31,7 @@
 
 #include "librc.h"
 
-#define GENDEP          RC_LIBDIR "/sh/gendepends.sh"
+#define GENDEP          RC_LIBEXECDIR "/sh/gendepends.sh"
 
 #define RC_DEPCONFIG    RC_SVCDIR "/depconfig"
 
@@ -565,27 +565,31 @@ mtime_check(const char *source, const char *target, bool newer,
 		return true;
 
 	if (newer) {
-		if (mtime < buf.st_mtime)
+		if (mtime < buf.st_mtime) {
+			if (rel == NULL)
+				return false;
 			retval = false;
+		}
 		if (rel != NULL) {
 			if (*rel < buf.st_mtime) {
 				if (file)
 					strlcpy(file, target, PATH_MAX);
 				*rel = buf.st_mtime;
 			}
-		} else
-			return retval;
+		}
 	} else {
-		if (mtime > buf.st_mtime)
+		if (mtime > buf.st_mtime) {
+			if (rel == NULL)
+				return false;
 			retval = false;
+		}
 		if (rel != NULL) {
 			if (*rel > buf.st_mtime) {
 				if (file)
 					strlcpy(file, target, PATH_MAX);
 				*rel = buf.st_mtime;
 			}
-		} else
-			return retval;
+		}
 	}
 
 	/* If not a dir then reset errno */
@@ -643,6 +647,7 @@ static const DEPPAIR deppairs[] = {
 
 static const char *const depdirs[] =
 {
+	RC_SVCDIR,
 	RC_SVCDIR "/starting",
 	RC_SVCDIR "/started",
 	RC_SVCDIR "/stopping",
@@ -733,15 +738,15 @@ rc_deptree_update(void)
 	RC_STRING *s, *s2, *s2_np, *s3, *s4;
 	char *line = NULL;
 	size_t len = 0;
-	char *depend, *depends, *service, *type, *nosys;
+	char *depend, *depends, *service, *type, *nosys, *onosys;
 	size_t i, k, l;
 	bool retval = true;
 	const char *sys = rc_sys();
 
-	/* Some init scripts need RC_LIBDIR to source stuff
+	/* Some init scripts need RC_LIBEXECDIR to source stuff
 	   Ideally we should be setting our full env instead */
-	if (!getenv("RC_LIBDIR"))
-		setenv("RC_LIBDIR", RC_LIBDIR, 0);
+	if (!getenv("RC_LIBEXECDIR"))
+		setenv("RC_LIBEXECDIR", RC_LIBEXECDIR, 0);
 
 	/* Phase 1 - source all init scripts and print dependencies */
 	if (!(fp = popen(GENDEP, "r")))
@@ -797,6 +802,11 @@ rc_deptree_update(void)
 				continue;
 			}
 
+			/* Don't provide ourself */
+			if (strcmp(type, "iprovide") == 0 &&
+			    strcmp(depend, service) == 0)
+				continue;
+
 			/* .sh files are not init scripts */
 			l = strlen(depend);
 			if (l > 2 &&
@@ -836,17 +846,25 @@ rc_deptree_update(void)
 	 * work for them. This doesn't stop them from being run directly. */
 	if (sys) {
 		len = strlen(sys);
-		nosys = xmalloc(len + 3);
-		nosys[0] = 'n';
-		nosys[1] = 'o';
+		nosys = xmalloc(len + 1);
+		nosys[0] = '-';
 		for (i = 0; i < len; i++)
-			nosys[i + 2] = (char)tolower((unsigned char)sys[i]);
-		nosys[i + 2] = '\0';
+			nosys[i + 1] = (char)tolower((unsigned char)sys[i]);
+		nosys[i + 1] = '\0';
+
+		onosys = xmalloc(len + 3);
+		onosys[0] = 'n';
+		onosys[1] = 'o';
+		for (i = 0; i < len; i++)
+			onosys[i + 2] = (char)tolower((unsigned char)sys[i]);
+		onosys[i + 2] = '\0';
 
 		TAILQ_FOREACH_SAFE(depinfo, deptree, entries, depinfo_np)
 			if ((deptype = get_deptype(depinfo, "keyword")))
 				TAILQ_FOREACH(s, deptype->services, entries)
-					if (strcmp(s->value, nosys) == 0) {
+					if (strcmp(s->value, nosys) == 0 ||
+					    strcmp(s->value, onosys) == 0)
+					{
 						provide = get_deptype(depinfo, "iprovide");
 						TAILQ_REMOVE(deptree, depinfo, entries);
 						TAILQ_FOREACH(di, deptree, entries) {
@@ -865,6 +883,7 @@ rc_deptree_update(void)
 						}
 					}
 		free(nosys);
+		free(onosys);
 	}
 
 	/* Phase 3 - add our providers to the tree */
@@ -895,11 +914,20 @@ rc_deptree_update(void)
 			TAILQ_FOREACH(s, deptype->services, entries) {
 				di = get_depinfo(deptree, s->value);
 				if (!di) {
-					if (strcmp(deptype->type, "ineed") == 0)
+					if (strcmp(deptype->type, "ineed") == 0) {
 						fprintf (stderr,
 							 "Service `%s' needs non"
 							 " existant service `%s'\n",
 							 depinfo->service, s->value);
+						dt = get_deptype(depinfo, "broken");
+						if (!dt) {
+							dt = xmalloc(sizeof(*dt));
+							dt->type = xstrdup("broken");
+							dt->services = rc_stringlist_new();
+							TAILQ_INSERT_TAIL(&depinfo->depends, dt, entries);
+						}
+						rc_stringlist_addu(dt->services, s->value);
+					}
 					continue;
 				}
 
